@@ -312,7 +312,7 @@ def sort_dict_list_by_list(dict_list: List[dict], sort_value_list: List[str], na
     return ordered_list
 
 
-def find_all_parents(tree, target_list, parent_key="parent_id", key="id", children_key="children", value_key="name"):
+def find_all_parents(tree, target_list, parent_key="parent_id", key="id", children_key="children", name_key="name"):
     """
     查找树形结构中每个目标元素的所有父级（包括间接父级）
 
@@ -330,8 +330,9 @@ def find_all_parents(tree, target_list, parent_key="parent_id", key="id", childr
         for node in nodes:
             node_map[node[key]] = {
                 parent_key: node.get(parent_key, ''),
-                value_key: node.get(value_key, ''),
-                children_key: node.get(children_key, [])
+                name_key: node.get(name_key, ''),
+                children_key: node.get(children_key, []),
+                key: node[key]
             }
             if children_key in node and node[children_key]:
                 build_map(node[children_key])
