@@ -1,3 +1,6 @@
+import importlib
+
+
 def condition_by_between(filters: list, model, column, start_value, end_value):
     _filter = None
     if start_value is not None and end_value is not None:
@@ -10,8 +13,9 @@ def condition_by_in(filters: list, model, column, value):
     _filter = None
     if value and isinstance(value, list):
         value = [_ for _ in value if _ not in [None, '', 'all']]
-        _filter = getattr(model, column).in_(value)
-        filters.append(_filter)
+        if value:
+            _filter = getattr(model, column).in_(value)
+            filters.append(_filter)
     return _filter
 
 
@@ -123,7 +127,42 @@ def condition_by_lte(filters: list, model, column, value):
     return _filter
 
 
-def condition_by_relation(filters: list, model, _column, _relation, _value, _end_value=None, _position="LR"):
+def condition_by_range(filters: list, model, column, value: list = None, is_contain_end=True, is_contain_start=True):
+    try:
+        sqlalchemy = importlib.import_module("sqlalchemy")
+    except ImportError:
+        raise Exception(f"sqlalchemy is not exist,run:pip install sqlalchemy==1.4.36")
+    _filter = None
+    if value and isinstance(value, list):
+        if len(value) == 2:
+            _filter1 = None
+            _filter2 = None
+            if is_contain_start:
+                _filter1 = condition_by_gte([], model, column, value[0])
+            else:
+                _filter1 = condition_by_gt([], model, column, value[0])
+            if is_contain_end:
+                _filter2 = condition_by_lte([], model, column, value[1])
+            else:
+                _filter2 = condition_by_lt([], model, column, value[1])
+            if _filter1 and _filter2:
+                _filter = sqlalchemy.and_(_filter1, _filter2)
+            elif _filter1 and not _filter2:
+                _filter = _filter1
+            elif not _filter1 and _filter2:
+                _filter = _filter2
+        elif len(value) == 1:
+            if is_contain_start:
+                _filter = condition_by_gte([], model, column, value[0])
+            else:
+                _filter = condition_by_gt([], model, column, value[0])
+    if _filter:
+        filters.append(_filter)
+    return _filter
+
+
+def condition_by_relation(filters: list, model, _column, _relation, _value, _end_value=None, _position="LR",
+                          is_contain_end=True, is_contain_start=True):
     if _relation == "in":
         condition_by_in(filters, model, _column, _value)
     elif _relation == "like":
@@ -154,6 +193,9 @@ def condition_by_relation(filters: list, model, _column, _relation, _value, _end
         condition_by_lt(filters, model, _column, _value)
     elif _relation == "lte" or _relation == ">=":
         condition_by_lte(filters, model, _column, _value)
+    elif _relation == "range":
+        condition_by_range(filters, model, _column, _value, is_contain_start=is_contain_start,
+                           is_contain_end=is_contain_end)
 
 
 def query_with_order_by(query, order_by_list: list = None):
